@@ -111,8 +111,8 @@ IMPL_LINK(ScSolverSuccessDialog, ClickHdl, weld::Button&, rBtn, void)
 ScCursorRefEdit::ScCursorRefEdit(std::unique_ptr<weld::Entry> xControl)
     : formula::RefEdit(std::move(xControl))
 {
-    xEntry->connect_key_press(Link<const KeyEvent&, bool>()); //acknowledge we first remove the old one
-    xEntry->connect_key_press(LINK(this, ScCursorRefEdit, KeyInputHdl));
+    mxEntry->connect_key_press(Link<const KeyEvent&, bool>()); //acknowledge we first remove the old one
+    mxEntry->connect_key_press(LINK(this, ScCursorRefEdit, KeyInputHdl));
 }
 
 void ScCursorRefEdit::SetCursorLinks( const Link<ScCursorRefEdit&,void>& rUp, const Link<ScCursorRefEdit&,void>& rDown )
@@ -316,7 +316,7 @@ void ScOptSolverDlg::Init(const ScAddress& rCursorPos)
 
     Size aSize(m_xContents->get_preferred_size());
     m_xContents->set_size_request(aSize.Width(), aSize.Height());
-    m_xScrollBar->connect_vadjustment_changed( LINK( this, ScOptSolverDlg, ScrollHdl ) );
+    m_xScrollBar->connect_vadjustment_value_changed( LINK( this, ScOptSolverDlg, ScrollHdl ) );
 
     m_xScrollBar->vadjustment_set_page_increment( EDIT_ROW_COUNT );
     m_xScrollBar->vadjustment_set_page_size( EDIT_ROW_COUNT );
@@ -385,8 +385,8 @@ void ScOptSolverDlg::ShowConditions()
     // allow to scroll one page behind the visible or stored rows
     tools::Long nVisible = nScrollPos + EDIT_ROW_COUNT;
     tools::Long nMax = std::max( nVisible, static_cast<tools::Long>(m_aConditions.size()) );
-    m_xScrollBar->vadjustment_configure(nScrollPos, 0, nMax + EDIT_ROW_COUNT, 1,
-                                        EDIT_ROW_COUNT - 1, EDIT_ROW_COUNT);
+    m_xScrollBar->vadjustment_configure(nScrollPos, nMax + EDIT_ROW_COUNT, 1, EDIT_ROW_COUNT - 1,
+                                        EDIT_ROW_COUNT);
 
     EnableButtons();
 }
