@@ -50,33 +50,28 @@ using namespace svt;
 
 namespace
 {
-    struct THeaderCellMapFunctorDispose
-    {
-        void operator()(const BrowseBox::THeaderCellMap::value_type& _aType)
+
+void disposeAndClearHeaderCell(BrowseBox::THeaderCellMap& _rHeaderCell)
+{
+    ::std::for_each(
+        _rHeaderCell.begin(), _rHeaderCell.end(),
+        [](const BrowseBox::THeaderCellMap::value_type& rType)
         {
-            css::uno::Reference<css::lang::XComponent> xComp(_aType.second, css::uno::UNO_QUERY);
-            OSL_ENSURE(xComp.is() || !_aType.second.is(), "THeaderCellMapFunctorDispose: invalid accessible cell (no XComponent)!");
+            css::uno::Reference<css::lang::XComponent> xComp(rType.second, css::uno::UNO_QUERY);
+            OSL_ENSURE(xComp.is() || !rType.second.is(),
+                       "THeaderCellMapFunctorDispose: invalid accessible cell (no XComponent)!");
             if (xComp.is())
                 try
                 {
                     xComp->dispose();
                 }
-                catch(const css::uno::Exception&)
+                catch (const css::uno::Exception&)
                 {
                     TOOLS_WARN_EXCEPTION("svtools", "THeaderCellMapFunctorDispose");
                 }
-        }
-    };
-
-    void disposeAndClearHeaderCell(BrowseBox::THeaderCellMap& _rHeaderCell)
-    {
-        ::std::for_each(
-                        _rHeaderCell.begin(),
-                        _rHeaderCell.end(),
-                        THeaderCellMapFunctorDispose()
-                            );
-        _rHeaderCell.clear();
-    }
+        });
+    _rHeaderCell.clear();
+}
 }
 
 // we're just measuring the "real" NavigationBar
@@ -598,15 +593,26 @@ void BrowseBox::SetColumnWidth( sal_uInt16 nItemId, tools::Long nWidth )
     tools::Long nOldWidth = mvCols[ nItemPos ]->Width();
 
     // adjust last column, if necessary
-    if ( IsVisible() && nItemPos == mvCols.size() - 1 )
+    if ( nItemPos == mvCols.size() - 1 )
     {
-        tools::Long nMaxWidth = pDataWin->GetSizePixel().Width();
-        nMaxWidth -= pDataWin->bAutoSizeLastCol
+        if ( IsVisible() )
+        {
+            tools::Long nMaxWidth = pDataWin->GetSizePixel().Width();
+            nMaxWidth -= pDataWin->bAutoSizeLastCol
                 ? GetFieldRect(nItemId).Left()
                 : GetFrozenWidth();
-        if ( pDataWin->bAutoSizeLastCol || nWidth > nMaxWidth )
+            if ( pDataWin->bAutoSizeLastCol || nWidth > nMaxWidth )
+            {
+                nWidth = nMaxWidth > 16 ? nMaxWidth : nOldWidth;
+            }
+        }
+        else if ( nWidth == LONG_MAX )
         {
-            nWidth = nMaxWidth > 16 ? nMaxWidth : nOldWidth;
+            // If we can’t calculate the maximum width because the window isn’t visible then it’s
+            // better to leave the width as it is than to set it to LONG_MAX. The last column width
+            // will be recalculated when the window is shown anyway because the window will be
+            // resized.
+            return;
         }
     }
 
@@ -2352,11 +2358,10 @@ void BrowseBox::CursorMoved()
     // before implementing more here, please adjust the EditBrowseBox
 
     if ( isAccessibleAlive() && HasFocus() )
-        commitTableEvent(
-            AccessibleEventId::ACTIVE_DESCENDANT_CHANGED,
-            Any( CreateAccessibleCell( GetCurRow(),GetColumnPos( GetCurColumnId() ) ) ),
-            Any()
-        );
+        commitTableEvent(AccessibleEventId::ACTIVE_DESCENDANT_CHANGED,
+                         Any(css::uno::Reference<css::accessibility::XAccessible>(
+                             CreateAccessibleCell(GetCurRow(), GetColumnPos(GetCurColumnId())))),
+                         Any());
 }
 
 void BrowseBox::LoseFocus()
