@@ -154,7 +154,6 @@ namespace sdr::contact {
 ViewObjectContact::ViewObjectContact(ObjectContact& rObjectContact, ViewContact& rViewContact)
 :   mrObjectContact(rObjectContact),
     mrViewContact(rViewContact),
-    maGridOffset(0.0, 0.0),
     mnActionChangedCount(0),
     mbLazyInvalidate(false)
 {
@@ -171,10 +170,7 @@ ViewObjectContact::~ViewObjectContact()
     if (!maObjectRange.isEmpty())
     {
         // invalidate in view
-        if(!getObjectRange().isEmpty())
-        {
-            GetObjectContact().InvalidatePartOfView(maObjectRange);
-        }
+        GetObjectContact().InvalidatePartOfView(maObjectRange);
     }
 
     // delete PrimitiveAnimation
@@ -291,30 +287,45 @@ void ViewObjectContact::ActionChildInserted(ViewContact& rChild)
     // GetObjectContact().InvalidatePartOfView(rChildVOC.getObjectRange());
 }
 
+// Check for animated primitives.
 void ViewObjectContact::checkForPrimitive2DAnimations()
 {
-    // remove old one
-    mpPrimitiveAnimation.reset();
-
-    // check for animated primitives
-    if(mxPrimitive2DSequence.empty())
-        return;
-
-    const bool bTextAnimationAllowed(GetObjectContact().IsTextAnimationAllowed());
-    const bool bGraphicAnimationAllowed(GetObjectContact().IsGraphicAnimationAllowed());
-
-    if(bTextAnimationAllowed || bGraphicAnimationAllowed)
+    // Somewhat odd structure here, because we are trying to avoid deleting and re-allocating the mpPrimitiveAnimation
+    // object, because we might be inside a call from the Scheduler, in which case we will be deleting an object
+    // on the call stack.
+    // Yes, this does still leave a possible situation where the user could turn animations off while we are
+    // animating and we could crash. I don't have a better solution right now.
+    //
+    drawinglayer::primitive2d::Primitive2DContainer aNewAnimatedPrimitives;
+    if(!mxPrimitive2DSequence.empty())
     {
-        AnimatedExtractingProcessor2D aAnimatedExtractor(GetObjectContact().getViewInformation2D(),
-            bTextAnimationAllowed, bGraphicAnimationAllowed);
-        aAnimatedExtractor.process(mxPrimitive2DSequence);
+        const bool bTextAnimationAllowed(GetObjectContact().IsTextAnimationAllowed());
+        const bool bGraphicAnimationAllowed(GetObjectContact().IsGraphicAnimationAllowed());
 
-        if(!aAnimatedExtractor.getPrimitive2DSequence().empty())
+        if(bTextAnimationAllowed || bGraphicAnimationAllowed)
         {
-            // derived primitiveList is animated, setup new PrimitiveAnimation
-            mpPrimitiveAnimation.reset( new sdr::animation::PrimitiveAnimation(*this, aAnimatedExtractor.extractPrimitive2DSequence()) );
+            AnimatedExtractingProcessor2D aAnimatedExtractor(GetObjectContact().getViewInformation2D(),
+                bTextAnimationAllowed, bGraphicAnimationAllowed);
+            aAnimatedExtractor.process(mxPrimitive2DSequence);
+
+            if(!aAnimatedExtractor.getPrimitive2DSequence().empty())
+            {
+                // derived primitiveList is animated, setup new PrimitiveAnimation
+                aNewAnimatedPrimitives = aAnimatedExtractor.extractPrimitive2DSequence();
+            }
         }
     }
+    if (!aNewAnimatedPrimitives.empty())
+    {
+        // derived primitiveList is animated, setup new PrimitiveAnimation
+        if (mpPrimitiveAnimation)
+            mpPrimitiveAnimation->SetPrimitives(std::move(aNewAnimatedPrimitives));
+        else
+            mpPrimitiveAnimation.reset( new sdr::animation::PrimitiveAnimation(*this, std::move(aNewAnimatedPrimitives)) );
+    }
+    else
+        // remove old one
+        mpPrimitiveAnimation.reset();
 }
 
 void ViewObjectContact::createPrimitive2DSequence(const DisplayInfo& rDisplayInfo, drawinglayer::primitive2d::Primitive2DDecompositionVisitor& rVisitor) const
@@ -339,15 +350,15 @@ void ViewObjectContact::createPrimitive2DSequence(const DisplayInfo& rDisplayInf
         // handle ghosted
         if(isPrimitiveGhosted(rDisplayInfo))
         {
-            const basegfx::BColor aRGBWhite(1.0, 1.0, 1.0);
-            const basegfx::BColorModifierSharedPtr aBColorModifier =
+            basegfx::BColor aRGBWhite(1.0, 1.0, 1.0);
+            basegfx::BColorModifierSharedPtr aBColorModifier =
                 std::make_shared<basegfx::BColorModifier_interpolate>(
                     aRGBWhite,
                     0.5);
             xRetval = drawinglayer::primitive2d::Primitive2DContainer{
                     new drawinglayer::primitive2d::ModifiedColorPrimitive2D(
                         std::move(xRetval),
-                        aBColorModifier)
+                        std::move(aBColorModifier))
             };
         }
     }
@@ -588,49 +599,49 @@ void ViewObjectContact::getPrimitive2DSequenceSubHierarchy(DisplayInfo& rDisplay
 // (->View) that has then all needed information
 const basegfx::B2DVector& ViewObjectContact::getGridOffset() const
 {
-    if (GetObjectContact().supportsGridOffsets())
-    {
-        if (fabs(maGridOffset.getX()) > 1000.0)
-        {
-            // Huge offsets are a hint for error -> usually the conditions for
-            // calculation have changed. E.g. - I saw errors with +/-5740, that
-            // was in the environment of massive external UNO API using LO as
-            // target.
-            // If conditions for this calculation change, it is usually required to call
-            // - ViewObjectContact::resetGridOffset(), or
-            // - ObjectContact::resetAllGridOffsets() or
-            // - ScDrawView::resetGridOffsetsForAllSdrPageViews()
-            // as it is done e.g. when zoom changes (see ScDrawView::RecalcScale()).
-            // Theoretically these resets have to be done for any precondition
-            // changed that is used in the calculation of that value (see
-            // ScDrawView::calculateGridOffsetForSdrObject).
-            // This is not complete and would be hard to do so.
-            // Since it is just a buffered value and re-calculation is not
-            // expensive (linear O(n)) we can just reset suspicious values here.
-            // Hopefully - when that non-linear ViewTransformation problem for
-            // the calc-view gets solved one day - all this can be removed
-            // again. For now, let's just reset here and force re-calculation.
-            // Add a SAL_WARN to inform about this.
-            SAL_WARN("svx", "Suspicious GridOffset value resetted (!)");
-            const_cast<ViewObjectContact*>(this)->maGridOffset.setX(0.0);
-            const_cast<ViewObjectContact*>(this)->maGridOffset.setY(0.0);
-        }
+    static const basegfx::B2DVector EMPTY(0.0, 0.0);
+    if (!GetObjectContact().supportsGridOffsets())
+        return EMPTY;
 
-        if(0.0 == maGridOffset.getX() && 0.0 == maGridOffset.getY() && GetObjectContact().supportsGridOffsets())
-        {
-            // create on-demand
-            GetObjectContact().calculateGridOffsetForViewObjectContact(const_cast<ViewObjectContact*>(this)->maGridOffset, *this);
-        }
+    if (moGridOffset.has_value() && fabs(moGridOffset->getX()) > 1000.0)
+    {
+        // Huge offsets are a hint for error -> usually the conditions for
+        // calculation have changed. E.g. - I saw errors with +/-5740, that
+        // was in the environment of massive external UNO API using LO as
+        // target.
+        // If conditions for this calculation change, it is usually required to call
+        // - ViewObjectContact::resetGridOffset(), or
+        // - ObjectContact::resetAllGridOffsets() or
+        // - ScDrawView::resetGridOffsetsForAllSdrPageViews()
+        // as it is done e.g. when zoom changes (see ScDrawView::RecalcScale()).
+        // Theoretically these resets have to be done for any precondition
+        // changed that is used in the calculation of that value (see
+        // ScDrawView::calculateGridOffsetForSdrObject).
+        // This is not complete and would be hard to do so.
+        // Since it is just a buffered value and re-calculation is not
+        // expensive (linear O(n)) we can just reset suspicious values here.
+        // Hopefully - when that non-linear ViewTransformation problem for
+        // the calc-view gets solved one day - all this can be removed
+        // again. For now, let's just reset here and force re-calculation.
+        // Add a SAL_WARN to inform about this.
+        SAL_WARN("svx", "Suspicious GridOffset value resetted (!)");
+        moGridOffset.reset();
     }
 
-    return maGridOffset;
+    if(!moGridOffset)
+    {
+        // create on-demand
+        moGridOffset.emplace();
+        GetObjectContact().calculateGridOffsetForViewObjectContact(*moGridOffset, *this);
+    }
+
+    return *moGridOffset;
 }
 
 void ViewObjectContact::resetGridOffset()
 {
     // reset buffered GridOffset itself
-    maGridOffset.setX(0.0);
-    maGridOffset.setY(0.0);
+    moGridOffset.reset();
 
     // also reset sequence to get a re-calculation when GridOffset changes
     mxPrimitive2DSequence.clear();
