@@ -73,24 +73,21 @@ void VulkanWindowContext::initializeContext() {
     PFN_vkGetInstanceProcAddr getInstanceProc = fGetInstanceProcAddr;
     skgpu::VulkanBackendContext& backendContext = fGlobalShared->backendContext;
     skgpu::VulkanExtensions extensions;
-    VkPhysicalDeviceFeatures2 features;
+    sk_gpu_test::TestVkFeatures features;
     if (!sk_gpu_test::CreateVkBackendContext(getInstanceProc,
                                              &backendContext,
                                              &extensions,
                                              &d->features,
-                                             &d->fDebugCallback,
+                                             &d->fDebugMessenger,
                                              &d->fPresentQueueIndex,
                                              fCanPresentFn,
                                              fDisplayParams->createProtectedNativeBackend())) {
-        sk_gpu_test::FreeVulkanFeaturesStructs(&d->features);
         fGlobalShared.reset();
-        sk_gpu_test::FreeVulkanFeaturesStructs(&features);
         return;
     }
 
     if (!extensions.hasExtension(VK_KHR_SURFACE_EXTENSION_NAME, 25) ||
         !extensions.hasExtension(VK_KHR_SWAPCHAIN_EXTENSION_NAME, 68)) {
-        sk_gpu_test::FreeVulkanFeaturesStructs(&d->features);
         fGlobalShared.reset();
         return;
     }
@@ -107,7 +104,6 @@ void VulkanWindowContext::initializeContext() {
                                             backendContext.fInstance,
                                             VK_NULL_HANDLE));
     if (!localGetPhysicalDeviceProperties) {
-        sk_gpu_test::FreeVulkanFeaturesStructs(&d->features);
         fGlobalShared.reset();
         return;
     }
@@ -125,8 +121,8 @@ void VulkanWindowContext::initializeContext() {
 
     GET_PROC_GLOBAL(DestroyInstance);
     GET_DEV_PROC_GLOBAL(DestroyDevice);
-    if (fGlobalShared->fDebugCallback != VK_NULL_HANDLE) {
-        GET_PROC_GLOBAL(DestroyDebugReportCallbackEXT);
+    if (fGlobalShared->fDebugMessenger != VK_NULL_HANDLE) {
+        GET_PROC_GLOBAL(DestroyDebugUtilsMessengerEXT);
     }
 
     backendContext.fMemoryAllocator =
@@ -498,7 +494,7 @@ void VulkanWindowContext::destroyContext() {
 
     fContext.reset();
     fShared.reset();
-
+    
     checkDestroyShared();
 }
 
@@ -520,8 +516,8 @@ void VulkanWindowContext::checkDestroyShared()
     }
 
 #ifdef SK_ENABLE_VK_LAYERS
-    if (fGlobalShared->fDebugCallback != VK_NULL_HANDLE) {
-        fGlobalShared->fDestroyDebugReportCallbackEXT(fGlobalShared->fInstance, fGlobalShared->fDebugCallback, nullptr);
+    if (fGlobalShared->fDebugMessenger != VK_NULL_HANDLE) {
+        fGlobalShared->fDestroyDebugUtilsMessengerEXT(fGlobalShared->fInstance, fGlobalShared->fDebugMessenger, nullptr);
     }
 #endif
 
@@ -531,8 +527,7 @@ void VulkanWindowContext::checkDestroyShared()
         fGlobalShared->fDestroyInstance(fGlobalShared->fInstance, nullptr);
         fGlobalShared->fInstance = VK_NULL_HANDLE;
     }
-
-    sk_gpu_test::FreeVulkanFeaturesStructs(&fGlobalShared->features);
+    
     fGlobalShared.reset();
 }
 
